Skip to contents

Print a concise and informative version of validation errors table.

Usage

view_config_val_errors(x)

Arguments

x

output of validate_config() or validate_hub_config().

Value

prints the errors attribute of x in an informative format to the viewer. Only available in interactive mode. The data frame the table is built from is returned by tabulate_config_val_errors().

Examples

if (FALSE) { # \dontrun{
config_path <- system.file("error-schema/tasks-errors.json",
  package = "hubUtils"
)
validate_config(config_path = config_path, config = "tasks") |>
  view_config_val_errors()
} # }