Print a concise and informative version of validation errors table.
Source:R/view_config_val_errors.R
view_config_val_errors.RdPrint a concise and informative version of validation errors table.
Arguments
- x
output of
validate_config()orvalidate_hub_config().
Value
prints the errors attribute of x in an informative format to the viewer. Only
available in interactive mode. The data frame the table is built from is
returned by tabulate_config_val_errors().
See also
validate_config(), tabulate_config_val_errors()
Other functions supporting config file validation:
render_config_val_errors_html(),
tabulate_config_val_errors(),
validate_config(),
validate_hub_config()
Examples
if (FALSE) { # \dontrun{
config_path <- system.file("error-schema/tasks-errors.json",
package = "hubUtils"
)
validate_config(config_path = config_path, config = "tasks") |>
view_config_val_errors()
} # }